@@ -22,7 +22,11 @@ def check(
     Add a check to a command.
 
     Args:
-        check: A coroutine as a check for this command.
+        check (typing.Callable): A coroutine as a check for this command. It should take \
+            a :class:`.MolterContext` and return a boolean.
+
+    Returns:
+        typing.Union[typing.Callable, MolterCommand]: The function or command decorated.
     """
 
     def wrapper(coro: MCT) -> MCT:
@@ -47,7 +51,10 @@ def has_permissions(
     Works for DMs.
 
     Args:
-        permissions (`interactions.Permissions`): A list of permissions to check.
+        permissions: A list of permissions to check.
+
+    Returns:
+        typing.Union[typing.Callable, MolterCommand]: The function or command decorated.
     """
 
     combined_permissions = interactions.Permissions(0)
@@ -76,7 +83,10 @@ def has_guild_permissions(
     Will fail in DMs.
 
     Args:
-        permissions (`interactions.Permissions`): A list of permissions to check.
+        permissions: A list of permissions to check.
+
+    Returns:
+        typing.Union[typing.Callable, MolterCommand]: The function or command decorated.
     """
 
     combined_permissions = interactions.Permissions(0)
@@ -99,7 +109,12 @@ def has_guild_permissions(
 
 
 def guild_only() -> typing.Callable[..., MCT]:
-    """A check to make the command only run in guilds."""
+    """
+    A check to make the command only run in guilds.
+
+    Returns:
+        typing.Union[typing.Callable, MolterCommand]: The function or command decorated.
+    """
 
     async def _guild_check(ctx: "MolterContext"):
         if not ctx.guild_id:
@@ -110,7 +125,12 @@ def guild_only() -> typing.Callable[..., MCT]:
 
 
 def dm_only() -> typing.Callable[..., MCT]:
-    """A check to make the command only run in DMs."""
+    """
+    A check to make the command only run in DMs.
+
+    Returns:
+        typing.Union[typing.Callable, MolterCommand]: The function or command decorated.
+    """
 
     async def _guild_check(ctx: "MolterContext"):
         if ctx.guild_id:
